
# Type: sequence feature relationship_subject




URI: [biolink:sequence_feature_relationship_subject](https://w3id.org/biolink/vocab/sequence_feature_relationship_subject)


## Domain and Range

[SequenceFeatureRelationship](SequenceFeatureRelationship.md) ->  <sub>REQ</sub> [GenomicEntity](GenomicEntity.md)

## Parents

 *  is_a: [subject](subject.md)

## Children

 *  [exon to transcript relationship➞subject](exon_to_transcript_relationship_subject.md)
 *  [gene to gene product relationship➞subject](gene_to_gene_product_relationship_subject.md)
 *  [transcript to gene relationship➞subject](transcript_to_gene_relationship_subject.md)

## Used by

 * [SequenceFeatureRelationship](SequenceFeatureRelationship.md)
